# Dear Distribution Packager. This use of require is intentional.
# Module::Install detects Build.PL usage and acts accordingly.

require 'Makefile.PL';

#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Task-Perl-Critic/Build.PL $
#     $Date: 2007-06-03 07:58:32 -0500 (Sun, 03 Jun 2007) $
#   $Author: clonezone $
# $Revision: 1577 $

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
#   indent-tabs-mode: nil
#   c-indentation-style: bsd
# End:
# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
